Trait secured_cipher::algorithm::AlgorithmProcess
source · pub trait AlgorithmProcess {
// Required method
fn process(&mut self, data: &[u8]) -> Vec<u8>;
}Required Methods
sourcefn process(&mut self, data: &[u8]) -> Vec<u8>
fn process(&mut self, data: &[u8]) -> Vec<u8>
Processes the provided data (either encrypts or decrypts, depending on the implementation).
This method applies the cipher’s permutation logic to the provided data, returning the processed data as a new vector of bytes.
Arguments
data- A byte slice of data to be processed (encrypted or decrypted).
Returns
A vector of bytes representing the processed data.